Index: chrome/test/chromedriver/test/run_py_tests.py |
diff --git a/chrome/test/chromedriver/test/run_py_tests.py b/chrome/test/chromedriver/test/run_py_tests.py |
index 111fea6e22e8a69422bcdd1f15e99de3b018291f..48083b2be96f9fdab7d45ca20e4c5cf84dfd0629 100755 |
--- a/chrome/test/chromedriver/test/run_py_tests.py |
+++ b/chrome/test/chromedriver/test/run_py_tests.py |
@@ -121,16 +121,16 @@ _ANDROID_NEGATIVE_FILTER['chrome_stable'] = ( |
_ANDROID_NEGATIVE_FILTER['chrome']) |
_ANDROID_NEGATIVE_FILTER['chrome_beta'] = ( |
_ANDROID_NEGATIVE_FILTER['chrome']) |
-_ANDROID_NEGATIVE_FILTER['chromium_test_shell'] = ( |
+_ANDROID_NEGATIVE_FILTER['chrome_shell'] = ( |
_ANDROID_NEGATIVE_FILTER['chrome'] + [ |
# ChromiumTestShell doesn't support multiple tabs. |
'ChromeDriverTest.testGetWindowHandles', |
'ChromeDriverTest.testSwitchToWindow', |
'ChromeDriverTest.testShouldHandleNewWindowLoadingProperly', |
] |
) |
_ANDROID_NEGATIVE_FILTER['chromedriver_webview_shell'] = ( |
- _ANDROID_NEGATIVE_FILTER['chromium_test_shell']) |
+ _ANDROID_NEGATIVE_FILTER['chrome_shell']) |
class ChromeDriverBaseTest(unittest.TestCase): |
@@ -121,16 +121,16 @@ _ANDROID_NEGATIVE_FILTER['chrome_stable'] = ( |
_ANDROID_NEGATIVE_FILTER['chrome'] + [ |
- # ChromiumTestShell doesn't support multiple tabs. |
+ # ChromeShell doesn't support multiple tabs. |
'ChromeDriverTest.testGetWindowHandles', |
'ChromeDriverTest.testSwitchToWindow', |